@@ -27,10 +27,10 @@ def post_error(code, message, cause):
         if cause is not None:
             error["cause"] = cause
         index_error_to_es(error)
-        log_info("post_error", "Error posted to the es index.", None)
+        log_info("Error posted to the es index.", None)
         return error
     except Exception as e:
-        log_exception("post_error", "Error Handler Failed.", None, e)
+        log_exception("Error Handler Failed.", None, e)
         return None
 
 
@@ -42,28 +42,33 @@ def post_error(code, message, cause):
 # taskID: Unique TASK ID generated for the current task.
 # state: State of the workflow pertaining to the current task.
 # status: Status of the workflow pertaining to the current task.
-def post_error_wf(code, message, jobId, taskId, state, status, cause):
+def post_error_wf(code, message, entity, cause):
     try:
         error = {
             "errorID": generate_error_id(),
             "code": code,
             "message": message,
             "timeStamp": eval(str(time.time()).replace('.', '')),
-            "jobID": jobId,
-            "taskID": taskId,
-            "state": state,
-            "status": status,
+            "jobID": entity["jobID"],
+            "taskID": entity["taskID"],
+            "state": entity["state"],
+            "status": "FAILED",
             "errorType": "wf-error"
         }
         if cause is not None:
             error["cause"] = cause
+        if entity["status"]:
+            error["status"] = entity["status"]
+        if entity["metadata"] is not None:
+            error["metadata"] = entity["metadata"]
+
         push_to_queue(error, anu_etl_wf_error_topic)
-        log_info("post_error_wf", "Error pushed to the wf error topic.", None)
+        log_info("Error pushed to the wf error topic.", None)
         index_error_to_es(error)
-        log_info("post_error_wf", "Error posted to the es index.", None)
+        log_info("Error posted to the es index.", None)
         return error
     except Exception as e:
-        log_exception("post_error_wf", "Error Handler WF Failed.", None, e)
+        log_exception("Error Handler WF Failed.", None, e)
         return None
 
 
